Stan Math Library: stan/math/rev/mat/fun/determinant.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
determinant.hpp File Reference
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int R, int C>
var | stan::math::determinant (const Eigen::Matrix< var, R, C > &m)

## Variable Documentation

vari** _adjARef

Definition at line 20 of file determinant.hpp.

int _cols

Definition at line 18 of file determinant.hpp.

int _rows

Definition at line 17 of file determinant.hpp.

double* A_

Definition at line 19 of file determinant.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.